"""This module contains all of the important meta-information for
Hypatia such as the author's name, the copyright and license, status,
and so on.

"""

__author__ = "Lillian Lemmer"
__copyright__ = "Copyright 2015 Lillian Lemmer"
__credits__ = ["Lillian Lemmer"]
__license__ = "MIT"
__maintainer__ = __author__
__site__ = "http://lillian-lemmer.github.io/hypatia/"
__email__ = "lillian.lynn.lemmer@gmail.com"
__status__ = "Development"

# specifically code contributors
__contributors__ = ["Lillian Lemmer",
                    "Eric James Michael Ritz",
                    "Brian Houston Morrow",
                    "William D. Jones"]

__version__ = '0.3.6'
